@@ -1,6 +1,6 @@
 
-from common import unittest2
-import common
+from common import unittest2, linesep
+
 import errno
 import pyuv
 import socket
@@ -14,6 +14,7 @@ if sys.platform == "win32":
 else:
     NONBLOCKING = (errno.EAGAIN, errno.EINPROGRESS, errno.EWOULDBLOCK)
 
+
 class PollTest(unittest2.TestCase):
 
     def setUp(self):
@@ -30,10 +31,10 @@ class PollTest(unittest2.TestCase):
         server.accept(client)
         self.client_connection = client
         client.start_read(self.on_client_connection_read)
-        client.write(b"PING"+common.linesep)
+        client.write(b"PING"+linesep)
 
     def on_client_connection_read(self, client, data, error):
-        self.assertEqual(data, b"PONG"+common.linesep)
+        self.assertEqual(data, b"PONG"+linesep)
         self.poll.close()
         self.client_connection.close()
         self.server.close()
@@ -60,11 +61,11 @@ class PollTest(unittest2.TestCase):
         if (events & pyuv.UV_READABLE):
             self.poll.stop()
             data = self.sock.recv(1024)
-            self.assertEqual(data, b"PING"+common.linesep)
+            self.assertEqual(data, b"PING"+linesep)
             self.poll.start(pyuv.UV_WRITABLE, self.poll_cb)
         elif (events & pyuv.UV_WRITABLE):
             self.poll.stop()
-            self.sock.send(b"PONG"+common.linesep)
+            self.sock.send(b"PONG"+linesep)
 
     def test_poll(self):
         self.server = pyuv.TCP(self.loop)
@@ -82,8 +83,11 @@ class PollTest(unittest2.TestCase):
             return
         self.connecting = True
         self.poll = pyuv.Poll(self.loop, self.sock.fileno())
+        self.assertEqual(self.sock.fileno(), self.poll.fileno())
         self.poll.start(pyuv.UV_WRITABLE, self.poll_cb)
         self.loop.run()
+        self.assertTrue(self.poll.closed)
+        self.assertEqual(self.poll.fileno(), -1)
 
 
 if __name__ == '__main__':
